JT xAPI Tools Example

This is a simple Flutter app demonstrating how to use the jt_xapi_tools package.

Setup

  1. Ensure you have your xAPI LRS credentials or a PHP Relay endpoint.
  2. Run flutter run -d chrome from this directory.

Testing the Relay

To test the Relay logic, ensure the relay.php provided in the root project is hosted on your server.