LRSInterface class abstract

Implementers

Constructors

LRSInterface()

Properties

hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

ensureInitialised() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryAndParseStatements(Map<String, dynamic> queryParameters) Future<List<Statement>?>
queryStatements(Map<String, dynamic> queryParameters) Future<Response?>
Queries the LRS for statements based on the provided queryParameters.
sendStatement(Statement statement) Future<Response?>
sendStatements(List<Statement> statements) Future<Response?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited