Activity class
- Implemented types
Constructors
- Activity({required String id, Definition? definition, String objectType = "Activity"})
-
Activity.fromId(ActivityId activityId, {String? description, String? customId, String? customName, Map<
String, dynamic> ? extensions}) -
factory
-
Activity.fromJson(Map<
String, dynamic> json) -
factory
Properties
- definition ↔ Definition?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- objectType → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appendStringToBaseId(
String newString) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited