Actor class

class to generate the actor. Just use the EMAIL in the mbox field as the toJson() will automatically add mailto

Implemented types

Constructors

Actor({required String name, String? mbox, Account? account, String objectType = 'Agent'})
Actor.fromJson(Map<String, dynamic> json)
factory

Properties

account Account?
final
hashCode int
The hash code for this object.
no setterinherited
mbox String?
final
name String
final
objectType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited