Actor constructor
Implementation
Actor({
required this.name,
this.mbox,
this.account,
this.objectType = 'Agent',
}) : assert(
mbox != null || account != null,
'An Actor must have either an mbox or an account',
);
Actor({
required this.name,
this.mbox,
this.account,
this.objectType = 'Agent',
}) : assert(
mbox != null || account != null,
'An Actor must have either an mbox or an account',
);