Context class
Constructors
-
Context({String? registration, Instructor? instructor, String? platform, ContextActivities? contextActivities, Map<
String, dynamic> ? extensions, String? revision, String? language}) -
Context.fromJson(Map<
String, dynamic> json) -
factory
Properties
- contextActivities → ContextActivities?
-
final
-
extensions
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instructor → Instructor?
-
final
- language → String?
-
final
- platform → String?
-
final
- registration → String?
-
final
- revision → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited