ContextActivities class

Constructors

ContextActivities({List<Activity>? parent, List<Activity>? grouping, List<Activity>? category, List<Activity>? other})
ContextActivities.fromJson(Map<String, dynamic>? json)
factory

Properties

category List<Activity>?
final
grouping List<Activity>?
final
hashCode int
The hash code for this object.
no setterinherited
other List<Activity>?
final
parent List<Activity>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited