Result class

Constructors

Result({bool? success, bool? completion, String? response, Score? score, Map<String, dynamic>? extensions})
Result.fromJson(Map<String, dynamic> json)
factory

Properties

completion bool?
final
extensions Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
response String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score Score?
final
success bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited