VerbId enum
CONSTANTS - start
Values
- completed → const VerbId
- attempted → const VerbId
- passed → const VerbId
- failed → const VerbId
- interacted → const VerbId
- scanned → const VerbId
- experienced → const VerbId
- updated → const VerbId
- edited → const VerbId
- launched → const VerbId
- registered → const VerbId
- unregistered → const VerbId
- enabled → const VerbId
- disabled → const VerbId
- removed → const VerbId
- loggedout → const VerbId
- loggedin → const VerbId
- pressed → const VerbId
- earned → const VerbId
- downloaded → const VerbId
- opened → const VerbId
- viewed → const VerbId
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited