xapi_connector_main
library
Classes
-
Account
-
-
Activity
-
-
ActivityConfig
-
-
Actor
-
class to generate the actor. Just use the EMAIL in the mbox field as the toJson() will automatically add mailto
-
Context
-
-
ContextActivities
-
-
Definition
-
-
Instructor
-
-
ManualLearningRecordStore
-
ManualLRS that lets you configure your endpoints so you can directly store xAPI statements.
Please bare in mind, storing keys in your app is not secure.
You would be better using the relay to send your statements to, but left this in so you can use it for inital testing!
-
Object
-
-
RelayLRS
-
RelayLRS allows you to forward your statements to a custom endpoint so you are not storing keys and secrets in your app.
In this implementation, the
storeKey is used to match a config file on your server that searches for any LRS creds with this key, and then
your server can handle the request. This means your app offloads all xAPI requests to your server for security reasons.
-
Result
-
-
Score
-
-
Statement
-
-
StatementObject
-
Base class for anything that can be the 'object' of a statement
-
Verb
-
-
VerbConfig
-
-
xAPIConnectorMain
-