Statement class
Constructors
- Statement({String version = "1.0.3", required Actor actor, required Verb verb, required StatementObject object, DateTime? timestamp, Result? result, Context? context})
- Statement.create({required Actor actor, required VerbId verbId, required ActivityId activityId, String version = "1.0.3", String? description, String? customActivityId, String? customActivityName, Result? result, Context? context, DateTime? optionalTimestamp})
-
Updated helper for creating statements using the config maps.
factory
-
Statement.fromJson(Map<
String, dynamic> json) -
factory
Properties
- actor → Actor
-
final
- context → Context?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- object → StatementObject
-
final
- result → Result?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
- verb → Verb
-
final
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited