Detects and returns the string name of the current host operating system platform.
Useful for populating context extensions or tracking client environment metadata instead of needing to retype this elsewhere.
Sends an individual xAPI statement request to the configured LRS.
Returns the http.Response from the LRS, or null if uninitialized or if an error occurs.
Sends a batch list of xAPI statements in a single bulk request to the configured LRS.
Returns the http.Response from the LRS, or null if uninitialized or if an error occurs.